@@ -12,10 +12,12 @@ from .herder import Herder
 parser = argparse.ArgumentParser(description='Manage daemonized (g)unicorns.')
 
 parser.add_argument('-u', '--unicorn', default='gunicorn', metavar='TYPE',
-                    choices=['unicorn', 'gunicorn'],
-                    help='The type of unicorn to manage (gunicorn, unicorn)')
+                    choices=['unicorn', 'gunicorn','gunicorn_django'],
+                    help='The type of unicorn to manage (gunicorn, gunicorn_django, unicorn)')
 parser.add_argument('-p', '--pidfile', metavar='PATH',
                     help='Path to the pidfile that unicorn will write')
+parser.add_argument('-t', '--timeout', default=30, type=int, metavar='30', dest='boot_timeout',
+                    help='Timeout in seconds to start workers')
 parser.add_argument('-v', '--version', action='version', version=__version__)
 parser.add_argument('args', nargs=argparse.REMAINDER,
                     help='Any additional arguments will be passed to unicorn/'
