@@ -12,7 +12,8 @@ log = logging.getLogger(__name__)
 
 COMMANDS = {
     'unicorn': 'unicorn -D -P "{pidfile}" {args}',
-    'gunicorn': 'gunicorn -D -p "{pidfile}" {args}'
+    'gunicorn': 'gunicorn -D -p "{pidfile}" {args}',
+    'gunicorn_django': 'gunicorn_django -D -p "{pidfile}" {args}'
 }
 
 MANAGED_PIDS = set([])
@@ -43,7 +44,7 @@ class Herder(object):
 
     """
 
-    def __init__(self, unicorn='gunicorn', pidfile=None, args=''):
+    def __init__(self, unicorn='gunicorn', pidfile=None, boot_timeout=30, args=''):
         """
 
         Creates a new Herder instance.
@@ -60,6 +61,7 @@ class Herder(object):
         self.unicorn = unicorn
         self.pidfile = '%s.pid' % self.unicorn if pidfile is None else pidfile
         self.args = args
+        self.boot_timeout = boot_timeout
 
         try:
             COMMANDS[self.unicorn]
@@ -96,11 +98,11 @@ class Herder(object):
         MANAGED_PIDS.add(process.pid)
 
         try:
-            with timeout(30):
+            with timeout(self.boot_timeout):
                 process.wait()
         except TimeoutError:
-            log.error('%s failed to daemonize within 30 seconds. Sending TERM '
-                      'and exiting.', self.unicorn)
+            log.error('%s failed to daemonize within %s seconds. Sending TERM '
+                      'and exiting.', self.unicorn, self.boot_timeout)
             if process.poll() is None:
                 process.terminate()
             return False
